/*
 * StringIterator
 * Copyright (C) 2008 Christian Schenk
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package org.christianschenk.stringutils;

import org.christianschenk.stopwatch.StopWatch;
import org.junit.Before;
import org.junit.Test;

public class StringIteratorTest {

	private String testString;
	private final int RUNS = 10;

	@Before
	public void setup() {
		this.testString = FileHelper.readFile("test.txt");
	}

	@Test
	public void perfTest() {
		for (final Runnable test : new Runnable[] { stringIterator, toCharArray, charAt, charSequence_charAt }) {
			int ms = 0;
			for (int i = 0; i < RUNS; i++) {
				StopWatch.start();
				test.run();
				StopWatch.stop();
				ms += StopWatch.getResult();
			}
			System.out.println("result: " + ((double) ms / RUNS));
		}
	}

	private final Runnable stringIterator = new Runnable() {
		public void run() {
			for (final char c : new StringIterator(testString)) {
				doSomething(c);
			}
		}
	};

	private final Runnable toCharArray = new Runnable() {
		public void run() {
			for (final char c : testString.toCharArray()) {
				doSomething(c);
			}
		}
	};

	private final Runnable charAt = new Runnable() {
		public void run() {
			for (int i = 0; i < testString.length(); i++) {
				doSomething(testString.charAt(i));
			}
		}
	};

	private final Runnable charSequence_charAt = new Runnable() {
		public void run() {
			final CharSequence charSeq = testString.subSequence(0, testString.length());
			for (int i = 0; i < testString.length(); i++) {
				doSomething(charSeq.charAt(i));
			}
		}
	};

	private void doSomething(final char c) {
		// does almost nothing
		int i = c; i++;
	}
}